@@ -1,12 +1,8 @@
-
-pub mod prf;
 pub mod hash;
+pub mod prf;
 pub mod prp;
 
-use aes::cipher::{
-    generic_array::GenericArray,
-    consts::U16
-};
+use aes::cipher::{consts::U16, generic_array::GenericArray};
 
 /*
  * Represents a 64-bit (8-byte) random seed.
@@ -20,7 +16,7 @@ pub type PRFKey = GenericArray<u8, U16>;
 pub type HashKey = GenericArray<u8, U16>;
 pub const NONCE_SIZE: usize = 16;
 
-pub trait PRF {
+pub trait Prf {
     fn new(key: &PRFKey) -> Self;
     fn encrypt_all(&self, data: &mut [AesBlock]);
 }
@@ -35,9 +31,8 @@ pub trait Hash {
 pub struct PRPError;
 pub type PRPResult<T> = Result<T, PRPError>;
 
-pub trait PRP<T>: Sized {
+pub trait Prp<T>: Sized {
     fn new(key: &[u8], seed: &SEED64) -> PRPResult<Self>;
     fn permute(&self, data: T) -> PRPResult<T>;
     fn invert(&self, data: T) -> PRPResult<T>;
 }
-
